Page 129 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 129

Home

    of courtesy, honesty, service to others, and self respect.
    An outstanding example of Chiang's magnanimous
    Christian character was revealed in a Radio Chungking
    message given when World War II ended in 1945:

    I am deeply moved when I think of the teaching of
    Jesus Christ that we should do unto others as we would

    militarism of Japan is our enemy, not the people of
    Japan. Although the armed forces of the enemy have
    been defeated and must be made to observe strictly all

    aw. c 1 1 14

    the terms of surrender, yet we should not for a moment
    think of revenge or heap abuses upon the innocent
    people of Japan.’

    Although Chiang Kai-shek was a proven and loyal
    ally to the United States throughout World War II, a
    systematic campaign was carried out under the Truman
    administration to betray Chiang and bring the

    administration to betray Chiang and bring the
    Communists to power in China. The Soviet Union had

    and

    the

    to

    been allowed to come into the war, just six days before
    Japan surrendered, and then take over Manchuria. The

    vast amounts of Japanese military hardware captured
    was given to Mao's communist guerrillas and Manchuria
    was used as a stronghold from which to conquer China.
    State Department aid to the Communists was so
    blatant that United States Ambassador to China, Patrick

    124

    The Secret Side of History

    called "The New Life Movement." This movement

    encouraged the people to follow the time-honored virtues

    have them do unto us and that we should love our

    enemies. . . . We have always said that the violent